//Disable All-Day Events v1.1
//1.1: base start time on slot duration

//Purpose:
//Prevents the default All-Day event type when creating events on the calendar
//in non-schedule views (Month, Horizon, Resource Daily/List)
//These new events will have a start time set to the current time
//and an end time populated from the default event duration

//Action Type: On Event Create
//Prevent Default Action: No

//----------- You shouldn’t need to edit below this line -------------------
disableAllDay(editEvent);

function disableAllDay(editEvent) {
  'use strict';

  //Declare required variables
  //More info on seedcodeCalendar.get can be found here:
  //https://www.seedcode.com/pmwiki/index.php?n=DayBackOnline.CustomActionObjects#seedcodeCalendar.get
  //More info on moment.js here: http://momentjs.com/docs/
  var defaultDuration = moment(
      seedcodeCalendar.get('config').defaultTimedEventDuration, 'HH:mm:ss')
    .diff(moment().startOf('day'), 'seconds');
  var currentTime = moment();
  var slot = seedcodeCalendar.get('config').slotDuration.split(':')[1];
  var minute = currentTime.get('minute') - (currentTime.get('minute') % slot);


  //If the event is set to all-day, set the new start and end times
  if (editEvent.allDay) {
    editEvent.allDay = false;
    editEvent.start.set('hour', currentTime.get('hour'))
      .set('minute', minute)
      .set('second', 0);
    editEvent.end = editEvent.start.clone().add(defaultDuration, 'seconds');
  }
}
